@@ -681,3 +681,41 @@ sub CanonEv($)
 
 #------------------------------------------------------------------------------
 1;  # end
+
+__END__
+
+=head1 NAME
+
+Image::ExifTool::Canon - Definitions for Canon EXIF maker notes
+
+=head1 SYNOPSIS
+
+This module is loaded automatically by Image::ExifTool when required.
+
+=head1 DESCRIPTION
+
+This module contains definitions required by Image::ExifTool to interpret
+Canon maker notes in EXIF information.
+
+=head1 AUTHOR
+
+Copyright 2003-2004, Phil Harvey (phil at owl.phy.queensu.ca)
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 REFERENCES
+
+=over 4
+
+=item http://park2.wakwak.com/~tsuruzoh/Computer/Digicams/exif-e.html
+
+=item ...plus lots of testing with my own camera.  ;)
+
+=back
+
+=head1 SEE ALSO
+
+L<Image::ExifTool|Image::ExifTool>
+
+=cut
