@@ -508,3 +508,41 @@ sub ProcessCanonCustom($$$)
 
 
 1;  # end
+
+__END__
+
+=head1 NAME
+
+Image::ExifTool::CanonCustom - Definitions for Canon custom functions
+
+=head1 SYNOPSIS
+
+This module is loaded automatically by Image::ExifTool when required.
+
+=head1 DESCRIPTION
+
+The Canon custom functions meta information is very specific to the
+camera model, and is found in both the EXIF maker notes and in the
+Canon RAW files.  This module contains the definitions necessary for
+Image::ExifTool to read this information.
+
+=head1 AUTHOR
+
+Copyright 2003-2004, Phil Harvey (phil at owl.phy.queensu.ca)
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 REFERENCES
+
+=over 4
+
+=item http://park2.wakwak.com/~tsuruzoh/Computer/Digicams/exif-e.html
+
+=back
+
+=head1 SEE ALSO
+
+L<Image::ExifTool|Image::ExifTool>
+
+=cut
