@@ -2096,3 +2096,41 @@ sub ProcessGeoTiff($$$$$)
 
 
 1;  #end
+
+__END__
+
+=head1 NAME
+
+Image::ExifTool::GeoTiff - Definitions for GeoTiff meta information
+
+=head1 SYNOPSIS
+
+This module is loaded automatically by Image::ExifTool when required.
+
+=head1 DESCRIPTION
+
+This module contains definitions required by Image::ExifTool to interpret
+GeoTiff meta information.  GeoTiff information is used in images to specify
+exact geometric mappings used to transform the image to real world
+coordinates.
+
+=head1 AUTHOR
+
+Copyright 2003-2004, Phil Harvey (phil at owl.phy.queensu.ca)
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 REFERENCES
+
+=over 4
+
+=item ftp://ftp.remotesensing.org/geotiff/libgeotiff/libgeotiff-1.1.4.tar.gz
+
+=back
+
+=head1 SEE ALSO
+
+L<Image::ExifTool|Image::ExifTool>
+
+=cut
