@@ -13,7 +13,7 @@ package Image::ExifTool::Minolta;
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 %Image::ExifTool::Minolta::Main = (
     GROUPS => { 0 => 'MakerNotes', 2 => 'Camera' },
@@ -296,6 +296,7 @@ $VERSION = '1.01';
             2 => '400',
             3 => '800',
             4 => 'auto',
+            5 => '64',
         },
     },
     37 => {
@@ -307,6 +308,8 @@ $VERSION = '1.01';
             3 => 'DiMAGE S404',
             4 => 'DiMAGE 7i',
             5 => 'DiMAGE 7Hi',
+            6 => 'DiMAGE A1',
+            7 => 'DiMAGE S414',
         },
     },
     38 => {
@@ -406,3 +409,39 @@ $VERSION = '1.01';
 );
 
 1;  # end
+
+__END__
+
+=head1 NAME
+
+Image::ExifTool::Minolta - Definitions for Minolta EXIF maker notes
+
+=head1 SYNOPSIS
+
+This module is loaded automatically by Image::ExifTool when required.
+
+=head1 DESCRIPTION
+
+This module contains definitions required by Image::ExifTool to interpret
+Minolta maker notes in EXIF information.
+
+=head1 AUTHOR
+
+Copyright 2003-2004, Phil Harvey (phil at owl.phy.queensu.ca)
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 REFERENCES
+
+=over 4
+
+=item http://www.dalibor.cz/minolta/makernote.htm
+
+=back
+
+=head1 SEE ALSO
+
+L<Image::ExifTool|Image::ExifTool>
+
+=cut
