@@ -185,3 +185,32 @@ sub ProcessPhotoshop($$$)
 
 
 1; # end
+
+
+__END__
+
+=head1 NAME
+
+Image::ExifTool::Photoshop - Definitions for Photoshop meta information
+
+=head1 SYNOPSIS
+
+This module is loaded automatically by Image::ExifTool when required.
+
+=head1 DESCRIPTION
+
+Photoshop writes its own format of meta information to the APP13 record in
+JPEG files.  This module contains the definitions to read this information.
+
+=head1 AUTHOR
+
+Copyright 2003-2004, Phil Harvey (phil at owl.phy.queensu.ca)
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
+
+=head1 SEE ALSO
+
+L<Image::ExifTool|Image::ExifTool>
+
+=cut
